==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/Paste/ts/Paste_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.js" line="+77"/>
        <source>Position</source>
        <translation>Pozicija</translation>
    </message>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotacija:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>Rotiraj prilepljene entitete&lt;br&gt;za ta kot</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale:</source>
        <translation>Razmerje:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>Povečaj/pomanjšaj entitete&lt;br&gt;za ta faktor</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>Zrcali prilepljene entitete&lt;br&gt;po vodoravni osi</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>Zrcali prilepljene entitete&lt;br&gt;po navpični osi</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translation>Prilepti vse entitete&lt;br&gt;na trenutno plast&lt;br&gt;namesto na izvorno</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translation>Na trenutno plast</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>Prepiši obstoječe plasti&lt;br&gt;v sliki, z plastmi&lt;br&gt;iz odložišča</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>Prepiši plasti</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>Prepiši obstoječe bloke&lt;br&gt;v sliki, z bloki&lt;br&gt;iz odložišča</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>Prepiši bloke</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translation>&amp;Prilepi</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/Paste/ts/Paste_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.js" line="+52"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paste</source>
        <translation>Prilepi</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Position</source>
        <translation>Pozicija</translation>
    </message>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotacija:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>Rotiraj prilepljene entitete&lt;br&gt;za ta kot</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scale:</source>
        <translation>Razmerje:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>Povečaj/pomanjšaj entitete&lt;br&gt;za ta faktor</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>Zrcali prilepljene entitete&lt;br&gt;po vodoravni osi</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>Zrcali prilepljene entitete&lt;br&gt;po navpični osi</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translation>Prilepti vse entitete&lt;br&gt;na trenutno plast&lt;br&gt;namesto na izvorno</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translation>Na trenutno plast</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>Prepiši obstoječe plasti&lt;br&gt;v sliki, z plastmi&lt;br&gt;iz odložišča</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>Prepiši plasti</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>Prepiši obstoječe bloke&lt;br&gt;v sliki, z bloki&lt;br&gt;iz odložišča</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>Prepiši bloke</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translation>&amp;Prilepi</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Reset to defaults every time tool is used</source>
        <translation>Ponastavi na privzeto vedno, ko je orodje uporabljeno</translation>
    </message>
</context>
</TS>
